#include <qpushbutton.h>
#include <qframe.h>
#include <qscrollview.h>
#include <qgrid.h>
#include <qhbox.h>
#include <qvbox.h>
#include <qvgroupbox.h>
#include <qlayout.h>
#include <qwidget.h>
#include <qlabel.h>
#include <qtabdialog.h>
#include <qspinbox.h>
#include <qlineedit.h>

#include "configurationdialog.h"
#include "configuration.h"

ConfigurationDialog::ConfigurationDialog(const Configuration &config, QWidget *parent, const char *name)
	: QTabDialog(parent, name, true),
	  workingConfiguration_(config)
{
	createWidgets();
	
	leUsername->setText(workingConfiguration_.username());
	lePassword->setText(workingConfiguration_.md5Password());
}

void ConfigurationDialog::createWidgets()
{
	setCaption(tr("Configuration"));
#ifdef QTOPIA
	setWState(WState_Reserved1);

	// Hide buttons
	setOkButton(QString::null);
#endif

	QVBox *main = new QVBox(this);
	main->setMargin(5);
	
	// Account data information
	QGroupBox *accountDataBox = new QGroupBox(1, Qt::Vertical, tr("Account"), main);
	
	QGrid *grid = new QGrid(2, QGrid::Horizontal, accountDataBox);
	grid->setSpacing(5);
	grid->setMargin(5);
	
	QLabel *lbUsername = new QLabel(tr("Username:"), grid);
	leUsername = new QLineEdit(grid);
	
	QLabel *lbPassword = new QLabel(tr("Password:"), grid);
	lePassword = new QLineEdit(grid);
	lePassword->setEchoMode(QLineEdit::Password);
	
	addTab(main, tr("General"));
}

void ConfigurationDialog::showEvent(QShowEvent *)
{
#ifdef QTOPIA
	showMaximized();
#endif;
}

int ConfigurationDialog::exec()
{
	loadWidgetPosition(this, qConfig.getConfigName(), "ConfigDialog");
	int result = QTabDialog::exec();
	
	if (result == QDialog::Accepted)
	{
		workingConfiguration_.setUsername(leUsername->text());
		if (lePassword->text() != workingConfiguration_.md5Password())
			workingConfiguration_.setPassword(lePassword->text());
	}
	
	saveWidgetPosition(this, qConfig.getConfigName(), "ConfigDialog");	
	return result;
}