/*
 * Copyright (C) 2007 Andre Beckedorf <evilJazz _AT_ katastrophos _DOT_ net>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef QSCROBBLER_H_INCLUDED
#define QSCROBBLER_H_INCLUDED

#include <qmainwindow.h>
#include <qdialog.h>
#include <qstring.h>
#include <qdatetime.h>

class Configuration;
class AudioScrobbler;
class QLabel;
class QProgressBar;
class QTimer;
class QListView;
class QVGroupBox;
class QWidgetStack;

class QScrobbler: public QWidget
{
	Q_OBJECT

public:
	QScrobbler();
	virtual ~QScrobbler();
	
protected:
	void closeEvent(QCloseEvent *);
	
private:
    AudioScrobbler *scrobbler;
    QLabel *currentlyPlayingLabel;
    QProgressBar *progressBar;
    QTime time;
    QTime pauseTime;
    int pauseTimeDelta;
    QTimer *updateTimer;
    QTimer *filePollTimer;
    QVGroupBox *gbox0;
    QListView *scrobbledTracksListView;
    QVGroupBox *gbox1;
    QWidgetStack *progressStack;
    QLabel *progressStatus;
    
#ifndef QTOPIA
    QDateTime lastDateTimeOfPolledFile;
    QString getTemporaryPlaybackStatusFileName();
#endif    

    void updateScrobblerSettings();
    
	void setCurrentSong(const QString &title, const QString &artist, const QString &album, int length);
	void removeCurrentSong();
	
	void setCurrentSongPaused();
	void setCurrentSongUnpaused();
    
private slots:
	void showSettings();
	void about();
	void updateTimerTriggered();
	void clearScrobbledTracksList();

	QString deescapeString(const QString &in);
	void filePollTimerTriggered();
	
	void cacheSaved();
	void songAddedForSubmission(const QString&);

    void mediaPlayerMessage(const QCString &msg, const QByteArray &data);
};

#endif // QSCROBBLER_H_INCLUDED
